# Changelog

## Version 0.0.9 (2024/03/13)


### Pull Requests Merged

* [PR 14](https://github.com/ghiggi/pycolorbar/pull/14) - Add semi-automated changelog generation, by [@sphamba](https://github.com/sphamba)
* [PR 12](https://github.com/ghiggi/pycolorbar/pull/12) - Fix GitHub automatic release, by [@sphamba](https://github.com/sphamba)


## Version 0.0.1 (2023-06-10)

First release of pycolorbar
